==> python_search-0.9.7.tar.gz: python_search-0.9.7/python_search/events/run_performed/dataset.py <==
from __future__ import annotations

from pyspark.sql.types import StructType, StructField, StringType, IntegerType

from python_search.config import DataConfig
from python_search.data_collector import GenericDataCollector


class EntryExecutedDataset:
    """
    Poit of access for the searches performed
    This is the place to keep the source of truth for the schema as well
    """

    columns = ["key", "query_input", "shortcut", "rank_uuid", "timestamp"]
    FILE_NAME = "run_performed"
    NEW_FILE_NAME = "searches_performed"
    CLEAN_PATH = DataConfig.CLEAN_EVENTS_FOLDER + "/" + FILE_NAME
    SCHEMA = StructType(
        [
            StructField("key", StringType(), True),
            StructField("query_input", StringType(), True),
            StructField("shortcut", StringType(), True),
            StructField("rank_uuid", StringType(), True),
            StructField("rank_position", IntegerType(), True),
            StructField("timestamp", StringType(), True),
        ]
    )

    def __init__(self, spark=None):
        from pyspark.sql.session import SparkSession

        self.spark = spark if spark else SparkSession.builder.getOrCreate()

    def load_old(self):
        """
        Load old original events stored via spark-streaming
        """
        data_location = "file://" + DataConfig.SEARCH_RUNS_PERFORMED_FOLDER
        print("Loading data from: {}".format(data_location))
        return self.spark.read.format("parquet").load_old(data_location)

    def load_clean(self):
        return self.spark.read.format("parquet").schema(EntryExecutedDataset.SCHEMA).load(self.CLEAN_PATH)

    def load_new(self):
        from pyspark.sql.session import SparkSession


        spark = SparkSession.builder.getOrCreate()
        result_df = spark.read.json(
            GenericDataCollector().data_location(EntryExecutedDataset.NEW_FILE_NAME),
            schema=EntryExecutedDataset.SCHEMA,
        )

        return result_df

==> python_search-0.10.5.tar.gz: python_search-0.10.5/python_search/events/run_performed/dataset.py <==
from __future__ import annotations

from pyspark.sql.types import StructType, StructField, StringType, IntegerType

from python_search.config import DataConfig
from python_search.data_collector import GenericDataCollector


class EntryExecutedDataset:
    """
    Poit of access for the searches performed
    This is the place to keep the source of truth for the schema as well
    """

    columns = ["key", "query_input", "shortcut", "rank_uuid", "timestamp"]
    FILE_NAME = "run_performed"
    NEW_FILE_NAME = "searches_performed"
    CLEAN_PATH = DataConfig.CLEAN_EVENTS_FOLDER + "/" + FILE_NAME
    SCHEMA = StructType(
        [
            StructField("key", StringType(), True),
            StructField("query_input", StringType(), True),
            StructField("shortcut", StringType(), True),
            StructField("rank_uuid", StringType(), True),
            StructField("rank_position", IntegerType(), True),
            StructField("timestamp", StringType(), True),
        ]
    )

    def __init__(self, spark=None):
        from pyspark.sql.session import SparkSession

        self.spark = spark if spark else SparkSession.builder.getOrCreate()

    def load_old(self):
        """
        Load old original events stored via spark-streaming
        """
        data_location = "file://" + DataConfig.SEARCH_RUNS_PERFORMED_FOLDER
        print("Loading data from: {}".format(data_location))
        return self.spark.read.format("parquet").load_old(data_location)

    def load_clean(self):
        return (
            self.spark.read.format("parquet")
            .schema(EntryExecutedDataset.SCHEMA)
            .load(self.CLEAN_PATH)
        )

    def load_new(self):
        from pyspark.sql.session import SparkSession

        spark = SparkSession.builder.getOrCreate()
        result_df = spark.read.json(
            GenericDataCollector().data_location(EntryExecutedDataset.NEW_FILE_NAME),
            schema=EntryExecutedDataset.SCHEMA,
        )

        return result_df
